# Welcome to FlashInfer-Bench Python API documentation!

[Blog Post](https://flashinfer.ai/2025/10/21/flashinfer-bench.html) | [GitHub](https://github.com/flashinfer-ai/flashinfer-bench/) | [Slack (Join channel #flashinfer-bench)](https://join.slack.com/t/flashinfer/shared_invite/zt-379wct3hc-D5jR~1ZKQcU00WHsXhgvtA)

FlashInfer-Bench is a comprehensive benchmark and infrastructure designed to create a "virtuous cycle" where AI can automatically optimize and improve the core GPU kernels of the AI systems it runs on. It provides a systematic framework to identify performance bottlenecks, generate solutions, and deploy them immediately into production.

```{toctree}
:maxdepth: 2
:caption: API Reference

rst/agents
rst/apply
rst/compile
rst/data
rst/tracing
```
